import numpy as np
import statsmodels.api as sm
import matplotlib.pyplot as plt


def plot_numbers(time_series, plot_name):
    t = np.arange(0, len(time_series), 1)
    fig, ax = plt.subplots()
    ax.plot(t, time_series)
    ax.grid()
    plt.show()
    fig.savefig(f"{plot_name}.png")


def read_numbers_from_file(file_path):
    lines = open(file_path, "rt").readlines()[1:]
    lines = [line.strip() for line in lines]
    file_numbers = [float(nr) for nr in lines]
    return file_numbers


def arima_next_point(timeseries):
    # Fit an ARIMA model to the time series
    arima_model = sm.tsa.ARIMA(timeseries, order=(1, 0, 0))
    arima_result = arima_model.fit()

    # Make a one-step-ahead prediction
    forecast = arima_result.forecast()
    next_point = forecast[0]

    return next_point


def iterate_arima(numbers, window_size, steps=1):
    predicted_numbers = list(numbers[:window_size])

    for it in range(window_size, len(numbers), steps):
        window = numbers[it-window_size: it]

        arima_model = sm.tsa.ARIMA(window, order=(1, 0, 0))
        arima_result = arima_model.fit()
        forecast = arima_result.forecast(steps)
        predicted_numbers.extend(forecast[0:steps])

    return predicted_numbers[:len(numbers)]





def main():
    numbers_nuclear = read_numbers_from_file("nuclear.txt")
    plot_numbers(numbers_nuclear, "original")
    predicted_numbers = iterate_arima(numbers_nuclear, 3)
    plot_numbers(predicted_numbers, "predicted")


main()


